<?php

/**
 * Netify provisioning controller.
 *
 * @category   apps
 * @package    netify
 * @subpackage controllers
 * @author     eGloo <team@egloo.ca>
 * @copyright  2016 eGloo
 * @license    http://www.gnu.org/copyleft/gpl.html GNU General Public License version 3 or later
 * @link       https://www.egloo.ca/netify/community
 */

///////////////////////////////////////////////////////////////////////////////
//
// This program is free software: you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation, either version 3 of the License, or
// (at your option) any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program.  If not, see <http://www.gnu.org/licenses/>.
//
///////////////////////////////////////////////////////////////////////////////

///////////////////////////////////////////////////////////////////////////////
// C L A S S
///////////////////////////////////////////////////////////////////////////////

/**
 * Netify provisioning controller.
 *
 * @category   apps
 * @package    netify
 * @subpackage controllers
 * @author     eGloo <team@egloo.ca>
 * @copyright  2016 eGloo
 * @license    http://www.gnu.org/copyleft/gpl.html GNU General Public License version 3 or later
 * @link       https://www.egloo.ca/netify/community
 */

class Provision extends ClearOS_Controller
{
    /**
     * Index view.
     *
     * @return view
     */

    function index()
    {
        $this->_common('index');
    }

    /**
     * Edit view.
     *
     * @return view
     */

    function edit()
    {
        $this->_common('edit');
    }

    /**
     * Common widget.
     *
     * @param string $type type
     *
     * @return view
     */

    function _common($type)
    {
        // Load libraries
        //---------------

        $this->lang->load('netify');
        $this->load->library('netify/Netifyd');

        // Set validation rules
        //---------------------
         
        $this->form_validation->set_policy('sink', 'netify/Netifyd', 'validate_sink');

        $form_ok = $this->form_validation->run();

        // Handle form submit
        //-------------------

        if (($this->input->post('submit') && $form_ok)) {
            try {
                $this->netifyd->set_sink($this->input->post('sink'));

                $this->netifyd->reset();

                $this->page->set_status_updated();
                redirect('/netify');
            } catch (Engine_Exception $e) {
                $this->page->view_exception($e->get_message());
                return;
            }
        }

        // Load view data
        //---------------

        try {
            $data = array(
                'uuid' => $this->netifyd->get_uuid(),
                'sink' => $this->netifyd->get_sink(),
                'version' => $this->netifyd->get_version() . '-' . $this->netifyd->get_release(),
            );
        } catch (Exception $e) {
            $this->page->view_exception($e);
            return;
        }

        // Load views
        //-----------

        $data['form_type'] = $type;

        $this->page->view_form('provision', $data, lang('netify_provision'));
    }
}
